==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/LogIpAddress.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LogGeographicalContext;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LogIpAddress
 */
@JsonPropertyOrder({ LogIpAddress.JSON_PROPERTY_GEOGRAPHICAL_CONTEXT, LogIpAddress.JSON_PROPERTY_IP,
        LogIpAddress.JSON_PROPERTY_SOURCE, LogIpAddress.JSON_PROPERTY_VERSION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LogIpAddress implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GEOGRAPHICAL_CONTEXT = "geographicalContext";
    private LogGeographicalContext geographicalContext;

    public static final String JSON_PROPERTY_IP = "ip";
    private String ip;

    public static final String JSON_PROPERTY_SOURCE = "source";
    private String source;

    public static final String JSON_PROPERTY_VERSION = "version";
    private String version;

    public LogIpAddress() {
    }

    /*
     * @JsonCreator public LogIpAddress(
     *
     * @JsonProperty(JSON_PROPERTY_IP) String ip,
     *
     * @JsonProperty(JSON_PROPERTY_SOURCE) String source,
     *
     * @JsonProperty(JSON_PROPERTY_VERSION) String version ) { this(); this.ip = ip; this.source = source; this.version
     * = version; }
     */

    public LogIpAddress geographicalContext(LogGeographicalContext geographicalContext) {

        this.geographicalContext = geographicalContext;
        return this;
    }

    /**
     * Get geographicalContext
     *
     * @return geographicalContext
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GEOGRAPHICAL_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LogGeographicalContext getGeographicalContext() {
        return geographicalContext;
    }

    @JsonProperty(JSON_PROPERTY_GEOGRAPHICAL_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGeographicalContext(LogGeographicalContext geographicalContext) {
        this.geographicalContext = geographicalContext;
    }

    /**
     * IP address
     *
     * @return ip
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "IP address")
    @JsonProperty(JSON_PROPERTY_IP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getIp() {
        return ip;
    }

    /**
     * Details regarding the source
     *
     * @return source
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Details regarding the source")
    @JsonProperty(JSON_PROPERTY_SOURCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSource() {
        return source;
    }

    /**
     * IP address version
     *
     * @return version
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "IP address version")
    @JsonProperty(JSON_PROPERTY_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getVersion() {
        return version;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LogIpAddress logIpAddress = (LogIpAddress) o;
        return Objects.equals(this.geographicalContext, logIpAddress.geographicalContext)
                && Objects.equals(this.ip, logIpAddress.ip) && Objects.equals(this.source, logIpAddress.source)
                && Objects.equals(this.version, logIpAddress.version);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(geographicalContext, ip, source, version);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LogIpAddress {\n");
        sb.append("    geographicalContext: ").append(toIndentedString(geographicalContext)).append("\n");
        sb.append("    ip: ").append(toIndentedString(ip)).append("\n");
        sb.append("    source: ").append(toIndentedString(source)).append("\n");
        sb.append("    version: ").append(toIndentedString(version)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/LogIpAddress.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LogGeographicalContext;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LogIpAddress
 */
@JsonPropertyOrder({ LogIpAddress.JSON_PROPERTY_GEOGRAPHICAL_CONTEXT, LogIpAddress.JSON_PROPERTY_IP,
        LogIpAddress.JSON_PROPERTY_SOURCE, LogIpAddress.JSON_PROPERTY_VERSION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class LogIpAddress implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GEOGRAPHICAL_CONTEXT = "geographicalContext";
    private LogGeographicalContext geographicalContext;

    public static final String JSON_PROPERTY_IP = "ip";
    private String ip;

    public static final String JSON_PROPERTY_SOURCE = "source";
    private String source;

    public static final String JSON_PROPERTY_VERSION = "version";
    private String version;

    public LogIpAddress() {
    }

    /*
     * @JsonCreator public LogIpAddress(
     *
     * @JsonProperty(JSON_PROPERTY_IP) String ip,
     *
     * @JsonProperty(JSON_PROPERTY_SOURCE) String source,
     *
     * @JsonProperty(JSON_PROPERTY_VERSION) String version ) { this(); this.ip = ip; this.source = source; this.version
     * = version; }
     */

    public LogIpAddress geographicalContext(LogGeographicalContext geographicalContext) {

        this.geographicalContext = geographicalContext;
        return this;
    }

    /**
     * Get geographicalContext
     *
     * @return geographicalContext
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GEOGRAPHICAL_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LogGeographicalContext getGeographicalContext() {
        return geographicalContext;
    }

    @JsonProperty(JSON_PROPERTY_GEOGRAPHICAL_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGeographicalContext(LogGeographicalContext geographicalContext) {
        this.geographicalContext = geographicalContext;
    }

    /**
     * IP address
     *
     * @return ip
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "IP address")
    @JsonProperty(JSON_PROPERTY_IP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getIp() {
        return ip;
    }

    /**
     * Details regarding the source
     *
     * @return source
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Details regarding the source")
    @JsonProperty(JSON_PROPERTY_SOURCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSource() {
        return source;
    }

    /**
     * IP address version
     *
     * @return version
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "IP address version")
    @JsonProperty(JSON_PROPERTY_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getVersion() {
        return version;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LogIpAddress logIpAddress = (LogIpAddress) o;
        return Objects.equals(this.geographicalContext, logIpAddress.geographicalContext)
                && Objects.equals(this.ip, logIpAddress.ip) && Objects.equals(this.source, logIpAddress.source)
                && Objects.equals(this.version, logIpAddress.version);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(geographicalContext, ip, source, version);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LogIpAddress {\n");
        sb.append("    geographicalContext: ").append(toIndentedString(geographicalContext)).append("\n");
        sb.append("    ip: ").append(toIndentedString(ip)).append("\n");
        sb.append("    source: ").append(toIndentedString(source)).append("\n");
        sb.append("    version: ").append(toIndentedString(version)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
